# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/gpu_cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import gpu_cluster_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_gpu__cluster__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/gpu_cluster_service.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/compute/v1/gpu_cluster_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a)yandex/cloud/compute/v1/gpu_cluster.proto\x1a&yandex/cloud/operation/operation.proto\".\n\x14GetGpuClusterRequest\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"t\n\x16ListGpuClustersRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\"m\n\x17ListGpuClustersResponse\x12\x39\n\x0cgpu_clusters\x18\x01 \x03(\x0b\x32#.yandex.cloud.compute.v1.GpuCluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa6\x02\n\x17\x43reateGpuClusterRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12L\n\x06labels\x18\x04 \x03(\x0b\x32<.yandex.cloud.compute.v1.CreateGpuClusterRequest.LabelsEntry\x12\x0f\n\x07zone_id\x18\x05 \x01(\t\x12G\n\x11interconnect_type\x18\x06 \x01(\x0e\x32,.yandex.cloud.compute.v1.GpuInterconnectType\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x18\x43reateGpuClusterMetadata\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"\x82\x02\n\x17UpdateGpuClusterRequest\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12L\n\x06labels\x18\x05 \x03(\x0b\x32<.yandex.cloud.compute.v1.UpdateGpuClusterRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x18UpdateGpuClusterMetadata\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"1\n\x17\x44\x65leteGpuClusterRequest\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"2\n\x18\x44\x65leteGpuClusterMetadata\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"`\n\x1fListGpuClusterOperationsRequest\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"r\n ListGpuClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"o\n\x1eListGpuClusterInstancesRequest\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"p\n\x1fListGpuClusterInstancesResponse\x12\x34\n\tinstances\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Instance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe8\t\n\x11GpuClusterService\x12\x8b\x01\n\x03Get\x12-.yandex.cloud.compute.v1.GetGpuClusterRequest\x1a#.yandex.cloud.compute.v1.GpuCluster\"0\x82\xd3\xe4\x93\x02*\x12(/compute/v1/gpuClusters/{gpu_cluster_id}\x12\x8a\x01\n\x04List\x12/.yandex.cloud.compute.v1.ListGpuClustersRequest\x1a\x30.yandex.cloud.compute.v1.ListGpuClustersResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/compute/v1/gpuClusters\x12\xab\x01\n\x06\x43reate\x12\x30.yandex.cloud.compute.v1.CreateGpuClusterRequest\x1a!.yandex.cloud.operation.Operation\"L\x82\xd3\xe4\x93\x02\x1c\"\x17/compute/v1/gpuClusters:\x01*\xb2\xd2*&\n\x18\x43reateGpuClusterMetadata\x12\nGpuCluster\x12\xbc\x01\n\x06Update\x12\x30.yandex.cloud.compute.v1.UpdateGpuClusterRequest\x1a!.yandex.cloud.operation.Operation\"]\x82\xd3\xe4\x93\x02-2(/compute/v1/gpuClusters/{gpu_cluster_id}:\x01*\xb2\xd2*&\n\x18UpdateGpuClusterMetadata\x12\nGpuCluster\x12\xc4\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.compute.v1.DeleteGpuClusterRequest\x1a!.yandex.cloud.operation.Operation\"e\x82\xd3\xe4\x93\x02**(/compute/v1/gpuClusters/{gpu_cluster_id}\xb2\xd2*1\n\x18\x44\x65leteGpuClusterMetadata\x12\x15google.protobuf.Empty\x12\xc2\x01\n\x0eListOperations\x12\x38.yandex.cloud.compute.v1.ListGpuClusterOperationsRequest\x1a\x39.yandex.cloud.compute.v1.ListGpuClusterOperationsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/compute/v1/gpuClusters/{gpu_cluster_id}/operations\x12\xbe\x01\n\rListInstances\x12\x37.yandex.cloud.compute.v1.ListGpuClusterInstancesRequest\x1a\x38.yandex.cloud.compute.v1.ListGpuClusterInstancesResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/compute/v1/gpuClusters/{gpu_cluster_id}/instancesBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_gpu__cluster__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,])




_GETGPUCLUSTERREQUEST = _descriptor.Descriptor(
  name='GetGpuClusterRequest',
  full_name='yandex.cloud.compute.v1.GetGpuClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpu_cluster_id', full_name='yandex.cloud.compute.v1.GetGpuClusterRequest.gpu_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=345,
)


_LISTGPUCLUSTERSREQUEST = _descriptor.Descriptor(
  name='ListGpuClustersRequest',
  full_name='yandex.cloud.compute.v1.ListGpuClustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.ListGpuClustersRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListGpuClustersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListGpuClustersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.ListGpuClustersRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='yandex.cloud.compute.v1.ListGpuClustersRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=463,
)


_LISTGPUCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='ListGpuClustersResponse',
  full_name='yandex.cloud.compute.v1.ListGpuClustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpu_clusters', full_name='yandex.cloud.compute.v1.ListGpuClustersResponse.gpu_clusters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListGpuClustersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=465,
  serialized_end=574,
)


_CREATEGPUCLUSTERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.CreateGpuClusterRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.CreateGpuClusterRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.CreateGpuClusterRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=871,
)

_CREATEGPUCLUSTERREQUEST = _descriptor.Descriptor(
  name='CreateGpuClusterRequest',
  full_name='yandex.cloud.compute.v1.CreateGpuClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.CreateGpuClusterRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.CreateGpuClusterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.CreateGpuClusterRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.CreateGpuClusterRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.compute.v1.CreateGpuClusterRequest.zone_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interconnect_type', full_name='yandex.cloud.compute.v1.CreateGpuClusterRequest.interconnect_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEGPUCLUSTERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=577,
  serialized_end=871,
)


_CREATEGPUCLUSTERMETADATA = _descriptor.Descriptor(
  name='CreateGpuClusterMetadata',
  full_name='yandex.cloud.compute.v1.CreateGpuClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpu_cluster_id', full_name='yandex.cloud.compute.v1.CreateGpuClusterMetadata.gpu_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=923,
)


_UPDATEGPUCLUSTERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.UpdateGpuClusterRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdateGpuClusterRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdateGpuClusterRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=871,
)

_UPDATEGPUCLUSTERREQUEST = _descriptor.Descriptor(
  name='UpdateGpuClusterRequest',
  full_name='yandex.cloud.compute.v1.UpdateGpuClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpu_cluster_id', full_name='yandex.cloud.compute.v1.UpdateGpuClusterRequest.gpu_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.compute.v1.UpdateGpuClusterRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.UpdateGpuClusterRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.UpdateGpuClusterRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.UpdateGpuClusterRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEGPUCLUSTERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=926,
  serialized_end=1184,
)


_UPDATEGPUCLUSTERMETADATA = _descriptor.Descriptor(
  name='UpdateGpuClusterMetadata',
  full_name='yandex.cloud.compute.v1.UpdateGpuClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpu_cluster_id', full_name='yandex.cloud.compute.v1.UpdateGpuClusterMetadata.gpu_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1186,
  serialized_end=1236,
)


_DELETEGPUCLUSTERREQUEST = _descriptor.Descriptor(
  name='DeleteGpuClusterRequest',
  full_name='yandex.cloud.compute.v1.DeleteGpuClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpu_cluster_id', full_name='yandex.cloud.compute.v1.DeleteGpuClusterRequest.gpu_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1238,
  serialized_end=1287,
)


_DELETEGPUCLUSTERMETADATA = _descriptor.Descriptor(
  name='DeleteGpuClusterMetadata',
  full_name='yandex.cloud.compute.v1.DeleteGpuClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpu_cluster_id', full_name='yandex.cloud.compute.v1.DeleteGpuClusterMetadata.gpu_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1289,
  serialized_end=1339,
)


_LISTGPUCLUSTEROPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListGpuClusterOperationsRequest',
  full_name='yandex.cloud.compute.v1.ListGpuClusterOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpu_cluster_id', full_name='yandex.cloud.compute.v1.ListGpuClusterOperationsRequest.gpu_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListGpuClusterOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListGpuClusterOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1341,
  serialized_end=1437,
)


_LISTGPUCLUSTEROPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListGpuClusterOperationsResponse',
  full_name='yandex.cloud.compute.v1.ListGpuClusterOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.compute.v1.ListGpuClusterOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListGpuClusterOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1439,
  serialized_end=1553,
)


_LISTGPUCLUSTERINSTANCESREQUEST = _descriptor.Descriptor(
  name='ListGpuClusterInstancesRequest',
  full_name='yandex.cloud.compute.v1.ListGpuClusterInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpu_cluster_id', full_name='yandex.cloud.compute.v1.ListGpuClusterInstancesRequest.gpu_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListGpuClusterInstancesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListGpuClusterInstancesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.ListGpuClusterInstancesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1555,
  serialized_end=1666,
)


_LISTGPUCLUSTERINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListGpuClusterInstancesResponse',
  full_name='yandex.cloud.compute.v1.ListGpuClusterInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='yandex.cloud.compute.v1.ListGpuClusterInstancesResponse.instances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListGpuClusterInstancesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1668,
  serialized_end=1780,
)

_LISTGPUCLUSTERSRESPONSE.fields_by_name['gpu_clusters'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_gpu__cluster__pb2._GPUCLUSTER
_CREATEGPUCLUSTERREQUEST_LABELSENTRY.containing_type = _CREATEGPUCLUSTERREQUEST
_CREATEGPUCLUSTERREQUEST.fields_by_name['labels'].message_type = _CREATEGPUCLUSTERREQUEST_LABELSENTRY
_CREATEGPUCLUSTERREQUEST.fields_by_name['interconnect_type'].enum_type = yandex_dot_cloud_dot_compute_dot_v1_dot_gpu__cluster__pb2._GPUINTERCONNECTTYPE
_UPDATEGPUCLUSTERREQUEST_LABELSENTRY.containing_type = _UPDATEGPUCLUSTERREQUEST
_UPDATEGPUCLUSTERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEGPUCLUSTERREQUEST.fields_by_name['labels'].message_type = _UPDATEGPUCLUSTERREQUEST_LABELSENTRY
_LISTGPUCLUSTEROPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_LISTGPUCLUSTERINSTANCESRESPONSE.fields_by_name['instances'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._INSTANCE
DESCRIPTOR.message_types_by_name['GetGpuClusterRequest'] = _GETGPUCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['ListGpuClustersRequest'] = _LISTGPUCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListGpuClustersResponse'] = _LISTGPUCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['CreateGpuClusterRequest'] = _CREATEGPUCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['CreateGpuClusterMetadata'] = _CREATEGPUCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['UpdateGpuClusterRequest'] = _UPDATEGPUCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateGpuClusterMetadata'] = _UPDATEGPUCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['DeleteGpuClusterRequest'] = _DELETEGPUCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteGpuClusterMetadata'] = _DELETEGPUCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['ListGpuClusterOperationsRequest'] = _LISTGPUCLUSTEROPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListGpuClusterOperationsResponse'] = _LISTGPUCLUSTEROPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['ListGpuClusterInstancesRequest'] = _LISTGPUCLUSTERINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListGpuClusterInstancesResponse'] = _LISTGPUCLUSTERINSTANCESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetGpuClusterRequest = _reflection.GeneratedProtocolMessageType('GetGpuClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETGPUCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetGpuClusterRequest)
  })
_sym_db.RegisterMessage(GetGpuClusterRequest)

ListGpuClustersRequest = _reflection.GeneratedProtocolMessageType('ListGpuClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTGPUCLUSTERSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListGpuClustersRequest)
  })
_sym_db.RegisterMessage(ListGpuClustersRequest)

ListGpuClustersResponse = _reflection.GeneratedProtocolMessageType('ListGpuClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTGPUCLUSTERSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListGpuClustersResponse)
  })
_sym_db.RegisterMessage(ListGpuClustersResponse)

CreateGpuClusterRequest = _reflection.GeneratedProtocolMessageType('CreateGpuClusterRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEGPUCLUSTERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateGpuClusterRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEGPUCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateGpuClusterRequest)
  })
_sym_db.RegisterMessage(CreateGpuClusterRequest)
_sym_db.RegisterMessage(CreateGpuClusterRequest.LabelsEntry)

CreateGpuClusterMetadata = _reflection.GeneratedProtocolMessageType('CreateGpuClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEGPUCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateGpuClusterMetadata)
  })
_sym_db.RegisterMessage(CreateGpuClusterMetadata)

UpdateGpuClusterRequest = _reflection.GeneratedProtocolMessageType('UpdateGpuClusterRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEGPUCLUSTERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateGpuClusterRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEGPUCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateGpuClusterRequest)
  })
_sym_db.RegisterMessage(UpdateGpuClusterRequest)
_sym_db.RegisterMessage(UpdateGpuClusterRequest.LabelsEntry)

UpdateGpuClusterMetadata = _reflection.GeneratedProtocolMessageType('UpdateGpuClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGPUCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateGpuClusterMetadata)
  })
_sym_db.RegisterMessage(UpdateGpuClusterMetadata)

DeleteGpuClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteGpuClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEGPUCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteGpuClusterRequest)
  })
_sym_db.RegisterMessage(DeleteGpuClusterRequest)

DeleteGpuClusterMetadata = _reflection.GeneratedProtocolMessageType('DeleteGpuClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEGPUCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteGpuClusterMetadata)
  })
_sym_db.RegisterMessage(DeleteGpuClusterMetadata)

ListGpuClusterOperationsRequest = _reflection.GeneratedProtocolMessageType('ListGpuClusterOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTGPUCLUSTEROPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListGpuClusterOperationsRequest)
  })
_sym_db.RegisterMessage(ListGpuClusterOperationsRequest)

ListGpuClusterOperationsResponse = _reflection.GeneratedProtocolMessageType('ListGpuClusterOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTGPUCLUSTEROPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListGpuClusterOperationsResponse)
  })
_sym_db.RegisterMessage(ListGpuClusterOperationsResponse)

ListGpuClusterInstancesRequest = _reflection.GeneratedProtocolMessageType('ListGpuClusterInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTGPUCLUSTERINSTANCESREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListGpuClusterInstancesRequest)
  })
_sym_db.RegisterMessage(ListGpuClusterInstancesRequest)

ListGpuClusterInstancesResponse = _reflection.GeneratedProtocolMessageType('ListGpuClusterInstancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTGPUCLUSTERINSTANCESRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListGpuClusterInstancesResponse)
  })
_sym_db.RegisterMessage(ListGpuClusterInstancesResponse)


DESCRIPTOR._options = None
_CREATEGPUCLUSTERREQUEST_LABELSENTRY._options = None
_UPDATEGPUCLUSTERREQUEST_LABELSENTRY._options = None

_GPUCLUSTERSERVICE = _descriptor.ServiceDescriptor(
  name='GpuClusterService',
  full_name='yandex.cloud.compute.v1.GpuClusterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1783,
  serialized_end=3039,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.compute.v1.GpuClusterService.Get',
    index=0,
    containing_service=None,
    input_type=_GETGPUCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_compute_dot_v1_dot_gpu__cluster__pb2._GPUCLUSTER,
    serialized_options=b'\202\323\344\223\002*\022(/compute/v1/gpuClusters/{gpu_cluster_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.compute.v1.GpuClusterService.List',
    index=1,
    containing_service=None,
    input_type=_LISTGPUCLUSTERSREQUEST,
    output_type=_LISTGPUCLUSTERSRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/compute/v1/gpuClusters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.compute.v1.GpuClusterService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEGPUCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\034\"\027/compute/v1/gpuClusters:\001*\262\322*&\n\030CreateGpuClusterMetadata\022\nGpuCluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.compute.v1.GpuClusterService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEGPUCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002-2(/compute/v1/gpuClusters/{gpu_cluster_id}:\001*\262\322*&\n\030UpdateGpuClusterMetadata\022\nGpuCluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.compute.v1.GpuClusterService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEGPUCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002**(/compute/v1/gpuClusters/{gpu_cluster_id}\262\322*1\n\030DeleteGpuClusterMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.compute.v1.GpuClusterService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTGPUCLUSTEROPERATIONSREQUEST,
    output_type=_LISTGPUCLUSTEROPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0223/compute/v1/gpuClusters/{gpu_cluster_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListInstances',
    full_name='yandex.cloud.compute.v1.GpuClusterService.ListInstances',
    index=6,
    containing_service=None,
    input_type=_LISTGPUCLUSTERINSTANCESREQUEST,
    output_type=_LISTGPUCLUSTERINSTANCESRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/compute/v1/gpuClusters/{gpu_cluster_id}/instances',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GPUCLUSTERSERVICE)

DESCRIPTOR.services_by_name['GpuClusterService'] = _GPUCLUSTERSERVICE

# @@protoc_insertion_point(module_scope)
